@@ -1410,8 +1410,10 @@ def get_overdue_amount(robo_idt_view):
 # nguyenhuuvinh4 START
 
 
-def get_registration_and_act_hi_var_from_dwh(appId):
-    SQL = "SELECT * DWROBOWLBL.LOS_USER_REGISTRATION_DATA s WHERE s.REGISTRATION_ID = '{}' OR s.EX_APPLICATION_ID = '{}'"
+def get_registration_and_act_hi_var_from_dwh(appIds):
+    appId = appIds.replace(',',"','")
+    print(appId)
+    SQL = "SELECT * DWROBOWLBL.LOS_USER_REGISTRATION_DATA s WHERE s.REGISTRATION_ID in ('{}') OR s.EX_APPLICATION_ID in ('{}') AND ROWNUM<2 ORDER BY ID DESC"
     SQL = SQL.format(appId, appId)
     print(SQL)
     connection = cx_Oracle.connect(
@@ -1426,7 +1428,7 @@ def get_registration_and_act_hi_var_from_dwh(appId):
         for row in cursorRegis:
             responseRegis.append(row)
     else:
-        SQL = "SELECT * DWROBOLENDING.LOS_USER_REGISTRATION_DATA s WHERE s.REGISTRATION_ID = '{}'"
+        SQL = "SELECT * DWROBOLENDING.LOS_USER_REGISTRATION_DATA s WHERE s.REGISTRATION_ID in ('{}') AND ROWNUM<2 ORDER BY ID DESC"
         SQL = SQL.format(appId)
         print(SQL)
         cursorRegis = connection.cursor()
